@@ -5,33 +5,23 @@ from django import template
 from django.templatetags.static import StaticNode, PrefixNode
 from django.apps import apps
 
-from npm_mjs.management.commands.transpile import LAST_RUN
+from npm_mjs.tools import get_last_run
 
 register = template.Library()
 
 
 class StaticTranspileNode(StaticNode):
-
     @classmethod
     def handle_simple(cls, path):
-        path = re.sub(
-            r'^js/(.*)\.mjs',
-            r'js/\1.js',
-            path
-        )
-        if apps.is_installed('django.contrib.staticfiles'):
+        path = re.sub(r"^js/(.*)\.mjs", r"js/\1.js", path)
+        if apps.is_installed("django.contrib.staticfiles"):
             from django.contrib.staticfiles.storage import staticfiles_storage
-            return (
-                staticfiles_storage.url(path) +
-                '?v=%s' % LAST_RUN['transpile']
-            )
+
+            return staticfiles_storage.url(path) + "?v=%s" % get_last_run("transpile")
         else:
-            return (
-                urljoin(
-                    PrefixNode.handle_simple("STATIC_URL"),
-                    quote(path)
-                ) + '?v=%s' % LAST_RUN['transpile']
-            )
+            return urljoin(
+                PrefixNode.handle_simple("STATIC_URL"), quote(path)
+            ) + "?v=%s" % get_last_run("transpile")
 
 
 @register.tag
